Hypothesis Python 2.6 Support
=============================

This is a module for adding Python 2.6 support to Hypothesis. It doesn't
add any additional functionality beyond that.

Note that unlike the main Hypothesis code it is licensed under the
GNU Affero General Public License. If you wish to use it under a different
license, please contact `licensing@hypothesis.works <licensing@hypothesis.works>`_.
